# -*- coding: iso-8859-1 -*-

import os
import sys
from math import log10

#-------------------------------------------------------------------------------
def main(run):
   debug = True
   open('/tmp/hostfile', 'w').write("""
[cli70cx]
cpu=1
mem=128

[localhost]
cpu=1
mem=128
""")
   
   open('/tmp/param.comm', 'w').write("""DEBUT()
P1 = 12.
print "Parameter P1 = %s" % P1
FIN()
""")

   prof = ASTER_PROFIL()
   
   prof['origine']  = 'as_run %s' % run['version']
   prof['mclient']  = run.system.info['local_host']
   prof['uclient']  = run.system.info['local_user']
   prof['serveur']  = run.system.info['local_host']
   prof['username'] = run.system.info['local_user']

   prof['actions'] = 'distribution'
   prof['mode']    = 'interactif'
   prof['version'] = 'NEW9'
   prof['debug']   = 'nodebug'
   prof.args['memjeveux'] = 8
   prof.args['tpmax']     = 60
   prof['memjob'] = 65536
   prof['tpsjob'] = 1
   prof.Set('D', {
      'type' : 'comm', 'isrep' : False, 'ul' : 1, 'compr' : False,
      'path' : '/tmp/param.comm' })
   prof.Set('D', {
      'type' : 'hostfile', 'isrep' : False, 'ul' : 0, 'compr' : False,
      'path' : '/tmp/hostfile' })
   prof.Set('R', {
      'type' : 'repe', 'isrep' : True, 'ul' : 0, 'compr' : False,
      'path' : '/tmp/test_param' })

   # get hostrc object
   hostrc = get_hostrc(run, prof)
   
   # timeout before rejected a job
   timeout = get_timeout(run, prof, 24.*3600.)

   # result directories
   resudir  = '/tmp/result_dir'
   if debug:
      flashdir = '/tmp/result_dir/flash'
   else:
      flashdir = None

   # list of parameters
   list_val = [
      { 'P1' : 111., }, { 'P1' : 222., }
   ]
   assert is_list_of_dict(list_val)
   nbval = len(list_val)
   
   # number of threads to follow execution
   numthread = 1

   # ----- Execute calcutions in parallel using a Dispatcher object
   # elementary task...
   task = DistribParametricTask(run=run, prof=prof, # IN
                          hostrc=hostrc,
                          nbmaxitem=0, timeout=timeout,
                          resudir=resudir, flashdir=flashdir,
                          info=1,
                          nbnook=0, exec_result=[])            # OUT
   # ... and dispatch task on 'list_tests'
   etiq = 'calc_%%0%dd' % (int(log10(nbval)) + 1)
   labels = [etiq % (i+1) for i in range(nbval)]
   couples = zip(labels, list_val)
   execution = Dispatcher(couples, task, numthread=numthread)
   return task

#-------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
ASTER_ROOT = os.environ['ASTER_ROOT']

# add .../ASTK_SERV/lib in import path
astk_serv_root = os.path.join(ASTER_ROOT, 'ASTK', 'ASTK_SERV')
sys.path.insert(0, os.path.join(astk_serv_root, 'lib'))

from as_run       import AsRunFactory
from as_profil    import ASTER_PROFIL
from as_common_func import get_hostrc, get_timeout
from as_param       import is_list_of_dict
from as_thread      import Dispatcher
from as_distrib     import DistribParametricTask
   
run = AsRunFactory(astk_serv_root)
task = main(run)

iret = 0
if task.nbnook > 0:
   iret = 4
run.Sortie(iret)

